==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaPole.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.enums.NazwySlownikow;
import pl.topteam.dps.enums.RodzajInformacji;
import pl.topteam.dps.enums.TypPolaInformacjiDodatkowej;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InformacjaDodatkowaPole extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_POLE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private JednostkaMiary jednostkaMiary;

    /**
     * INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnosc;

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private NazwySlownikow nazwaSlownika;

    /**
     * INFORMACJA_DODATKOWA_POLE.RODZAJ
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private RodzajInformacji rodzaj;

    /**
     * INFORMACJA_DODATKOWA_POLE.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypPolaInformacjiDodatkowej typ;

    /**
     * INFORMACJA_DODATKOWA_POLE.WYMAGANE
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean wymagane;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_POLE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public JednostkaMiary getJednostkaMiary() {
        return jednostkaMiary;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     *
     * @param jednostkaMiary
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJednostkaMiary(JednostkaMiary jednostkaMiary) {
        this.jednostkaMiary = jednostkaMiary;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public NazwySlownikow getNazwaSlownika() {
        return nazwaSlownika;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     *
     * @param nazwaSlownika
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwaSlownika(NazwySlownikow nazwaSlownika) {
        this.nazwaSlownika = nazwaSlownika;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.RODZAJ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public RodzajInformacji getRodzaj() {
        return rodzaj;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRodzaj(RodzajInformacji rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypPolaInformacjiDodatkowej getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypPolaInformacjiDodatkowej typ) {
        this.typ = typ;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.WYMAGANE
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getWymagane() {
        return wymagane;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.WYMAGANE
     *
     * @param wymagane
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWymagane(Boolean wymagane) {
        this.wymagane = wymagane;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaPole other = (InformacjaDodatkowaPole) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getJednostkaMiary() == null ? other.getJednostkaMiary() == null : this.getJednostkaMiary().equals(other.getJednostkaMiary()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getNazwaSlownika() == null ? other.getNazwaSlownika() == null : this.getNazwaSlownika().equals(other.getNazwaSlownika()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWymagane() == null ? other.getWymagane() == null : this.getWymagane().equals(other.getWymagane()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getJednostkaMiary() == null) ? 0 : getJednostkaMiary().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getNazwaSlownika() == null) ? 0 : getNazwaSlownika().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWymagane() == null) ? 0 : getWymagane().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", jednostkaMiary=").append(jednostkaMiary);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", nazwaSlownika=").append(nazwaSlownika);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", typ=").append(typ);
        sb.append(", wymagane=").append(wymagane);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowaPole.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.enums.NazwySlownikow;
import pl.topteam.dps.enums.RodzajInformacji;
import pl.topteam.dps.enums.TypPolaInformacjiDodatkowej;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InformacjaDodatkowaPole extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA_POLE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaDodatkowaId;

    /**
     * INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private JednostkaMiary jednostkaMiary;

    /**
     * INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnosc;

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private NazwySlownikow nazwaSlownika;

    /**
     * INFORMACJA_DODATKOWA_POLE.RODZAJ
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private RodzajInformacji rodzaj;

    /**
     * INFORMACJA_DODATKOWA_POLE.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypPolaInformacjiDodatkowej typ;

    /**
     * INFORMACJA_DODATKOWA_POLE.WYMAGANE
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean wymagane;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA_POLE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaDodatkowaId() {
        return informacjaDodatkowaId;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.INFORMACJA_DODATKOWA_ID
     *
     * @param informacjaDodatkowaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaDodatkowaId(Long informacjaDodatkowaId) {
        this.informacjaDodatkowaId = informacjaDodatkowaId;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public JednostkaMiary getJednostkaMiary() {
        return jednostkaMiary;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.JEDNOSTKA_MIARY
     *
     * @param jednostkaMiary
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJednostkaMiary(JednostkaMiary jednostkaMiary) {
        this.jednostkaMiary = jednostkaMiary;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnosc() {
        return kolejnosc;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.KOLEJNOSC
     *
     * @param kolejnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnosc(Integer kolejnosc) {
        this.kolejnosc = kolejnosc;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public NazwySlownikow getNazwaSlownika() {
        return nazwaSlownika;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.NAZWA_SLOWNIKA
     *
     * @param nazwaSlownika
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwaSlownika(NazwySlownikow nazwaSlownika) {
        this.nazwaSlownika = nazwaSlownika;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.RODZAJ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public RodzajInformacji getRodzaj() {
        return rodzaj;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.RODZAJ
     *
     * @param rodzaj
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRodzaj(RodzajInformacji rodzaj) {
        this.rodzaj = rodzaj;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypPolaInformacjiDodatkowej getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypPolaInformacjiDodatkowej typ) {
        this.typ = typ;
    }

    /**
     * @return INFORMACJA_DODATKOWA_POLE.WYMAGANE
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getWymagane() {
        return wymagane;
    }

    /**
     * INFORMACJA_DODATKOWA_POLE.WYMAGANE
     *
     * @param wymagane
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWymagane(Boolean wymagane) {
        this.wymagane = wymagane;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowaPole other = (InformacjaDodatkowaPole) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getInformacjaDodatkowaId() == null ? other.getInformacjaDodatkowaId() == null : this.getInformacjaDodatkowaId().equals(other.getInformacjaDodatkowaId()))
            && (this.getJednostkaMiary() == null ? other.getJednostkaMiary() == null : this.getJednostkaMiary().equals(other.getJednostkaMiary()))
            && (this.getKolejnosc() == null ? other.getKolejnosc() == null : this.getKolejnosc().equals(other.getKolejnosc()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getNazwaSlownika() == null ? other.getNazwaSlownika() == null : this.getNazwaSlownika().equals(other.getNazwaSlownika()))
            && (this.getRodzaj() == null ? other.getRodzaj() == null : this.getRodzaj().equals(other.getRodzaj()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getWymagane() == null ? other.getWymagane() == null : this.getWymagane().equals(other.getWymagane()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getInformacjaDodatkowaId() == null) ? 0 : getInformacjaDodatkowaId().hashCode());
        result = prime * result + ((getJednostkaMiary() == null) ? 0 : getJednostkaMiary().hashCode());
        result = prime * result + ((getKolejnosc() == null) ? 0 : getKolejnosc().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getNazwaSlownika() == null) ? 0 : getNazwaSlownika().hashCode());
        result = prime * result + ((getRodzaj() == null) ? 0 : getRodzaj().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getWymagane() == null) ? 0 : getWymagane().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", informacjaDodatkowaId=").append(informacjaDodatkowaId);
        sb.append(", jednostkaMiary=").append(jednostkaMiary);
        sb.append(", kolejnosc=").append(kolejnosc);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", nazwaSlownika=").append(nazwaSlownika);
        sb.append(", rodzaj=").append(rodzaj);
        sb.append(", typ=").append(typ);
        sb.append(", wymagane=").append(wymagane);
        sb.append("]");
        return sb.toString();
    }
}
